@@ -24,10 +24,10 @@ describe 'gnocchi::db' do
 
     context 'with postgresql backend' do
       let :params do
-        { :database_connection     => 'postgresql://gnocchi:gnocchi@localhost/gnocchi', }
+        { :database_connection => 'postgresql://gnocchi:gnocchi@localhost/gnocchi', }
       end
 
-      it { should contain_package('python-psycopg2').with_ensure('present') }
+      it { should contain_class('postgresql::lib::python') }
     end
 
     context 'with MySQL-python library as backend package' do
@@ -37,7 +37,8 @@ describe 'gnocchi::db' do
         }
       end
 
-      it { should contain_package('python-mysqldb').with_ensure('present') }
+      it { should contain_class('mysql::bindings') }
+      it { should contain_class('mysql::bindings::python') }
     end
 
     context 'with incorrect database_connection string' do
@@ -102,25 +103,24 @@ describe 'gnocchi::db' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
+        }))
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          if facts[:os_package_type] == 'debian' then
-            pymysql_pkg = 'python3-pymysql'
-          else
-            pymysql_pkg = 'python-pymysql'
-          end
           {
-            :pymysql_package_name => pymysql_pkg,
+            :pymysql_package_name => 'python3-pymysql',
           }
         end
       end
 
       it_behaves_like 'gnocchi::db'
-      it_behaves_like "gnocchi::db on #{facts[:osfamily]}"
+      it_behaves_like "gnocchi::db on #{facts[:os]['family']}"
     end
   end
 end
